pub async fn revoke_agent(
__arg0: State<AppState>,
user: CurrentUser,
__arg2: Path<Uuid>,
) -> Result<impl IntoResponse, ApiError>Expand description
Withdraws an agent’s token. The row stays, so its uploads keep an owner.
pub async fn revoke_agent(
__arg0: State<AppState>,
user: CurrentUser,
__arg2: Path<Uuid>,
) -> Result<impl IntoResponse, ApiError>Withdraws an agent’s token. The row stays, so its uploads keep an owner.