pub struct YearQuery {
pub year: i32,
}Expand description
The year being asked for. A year at a time is how a calendar is published and how an administrator checks one.
Fields
year: i32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for YearQuery
impl<'de> Deserialize<'de> for YearQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more