pub struct Pause {
pub id: Uuid,
pub started_at: DateTime<Utc>,
pub ended_at: Option<DateTime<Utc>>,
pub duration_seconds: Option<i32>,
pub manual: bool,
pub reason: Option<String>,
}Fields
id: Uuidstarted_at: DateTime<Utc>ended_at: Option<DateTime<Utc>>duration_seconds: Option<i32>manual: boolA break the employee entered by hand, as opposed to detected idleness.
reason: Option<String>The text they typed with it, where the policy keeps free text.