pub struct AlertPayload {
pub id: Uuid,
pub rule: AlertRule,
pub observed_seconds: i64,
pub against_seconds: Option<i64>,
pub subject_date: Option<NaiveDate>,
pub fired_at: DateTime<Utc>,
}Expand description
An alert as it fired. The figures are the ones it fired on, never re-derived: a message already read must not change under its reader (ADR 0018).
Fields
id: Uuidrule: AlertRuleobserved_seconds: i64against_seconds: Option<i64>subject_date: Option<NaiveDate>fired_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for AlertPayload
impl Clone for AlertPayload
Sourceimpl Debug for AlertPayload
impl Debug for AlertPayload
Sourceimpl<'de> Deserialize<'de> for AlertPayload
impl<'de> Deserialize<'de> for AlertPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, R: Row> FromRow<'a, R> for AlertPayloadwhere
&'a str: ColumnIndex<R>,
Uuid: Decode<'a, R::Database> + Type<R::Database>,
AlertRule: Decode<'a, R::Database> + Type<R::Database>,
i64: Decode<'a, R::Database> + Type<R::Database>,
Option<i64>: Decode<'a, R::Database> + Type<R::Database>,
Option<NaiveDate>: Decode<'a, R::Database> + Type<R::Database>,
DateTime<Utc>: Decode<'a, R::Database> + Type<R::Database>,
impl<'a, R: Row> FromRow<'a, R> for AlertPayloadwhere
&'a str: ColumnIndex<R>,
Uuid: Decode<'a, R::Database> + Type<R::Database>,
AlertRule: Decode<'a, R::Database> + Type<R::Database>,
i64: Decode<'a, R::Database> + Type<R::Database>,
Option<i64>: Decode<'a, R::Database> + Type<R::Database>,
Option<NaiveDate>: Decode<'a, R::Database> + Type<R::Database>,
DateTime<Utc>: Decode<'a, R::Database> + Type<R::Database>,
Sourceimpl PartialEq for AlertPayload
impl PartialEq for AlertPayload
Sourceimpl Serialize for AlertPayload
impl Serialize for AlertPayload
impl StructuralPartialEq for AlertPayload